@@ -168,7 +168,7 @@ def get_bucket_website_hostname(bucket_name):
 
 def get_forwarded_for_host(headers):
     x_forwarded_header = re.split(r",\s?", headers.get("X-Forwarded-For", ""))
-    host = x_forwarded_header[len(x_forwarded_header) - 1]
+    host = x_forwarded_header[-1]
     return host
 
 
@@ -198,13 +198,13 @@ def authenticate_presign_url(method, path, headers, data=None):
     if forwarded_for:
         url = re.sub("://[^/]+", "://%s" % forwarded_for, url)
 
-    LOGGER.debug("Received presign S3 URL: %s" % url)
+    LOGGER.debug("Received presign S3 URL: %s", url)
 
     sign_headers = {}
     query_string = {}
 
-    is_v2 = all([p in query_params for p in SIGNATURE_V2_PARAMS])
-    is_v4 = all([p in query_params for p in SIGNATURE_V4_PARAMS])
+    is_v2 = all(p in query_params for p in SIGNATURE_V2_PARAMS)
+    is_v4 = all(p in query_params for p in SIGNATURE_V4_PARAMS)
 
     # Add overrided headers to the query string params
     for param_name, header_name in ALLOWED_HEADER_OVERRIDES.items():
@@ -298,7 +298,7 @@ def authenticate_presign_url(method, path, headers, data=None):
             else request_dict["url"]
         )
 
-    if not is_v2 and any([p in query_params for p in SIGNATURE_V2_PARAMS]):
+    if not is_v2 and any(p in query_params for p in SIGNATURE_V2_PARAMS):
         response = requests_error_response_xml_signature_calculation(
             code=403,
             message="Query-string authentication requires the Signature, Expires and AWSAccessKeyId parameters",
@@ -309,7 +309,7 @@ def authenticate_presign_url(method, path, headers, data=None):
             method, path, headers, data, url, query_params, request_dict
         )
 
-    if not is_v4 and any([p in query_params for p in SIGNATURE_V4_PARAMS]):
+    if not is_v4 and any(p in query_params for p in SIGNATURE_V4_PARAMS):
         response = requests_error_response_xml_signature_calculation(
             code=403,
             message="Query-string authentication requires the X-Amz-Algorithm, \
@@ -324,7 +324,7 @@ def authenticate_presign_url(method, path, headers, data=None):
         )
 
     if response is not None:
-        LOGGER.info("Presign signature calculation failed: %s" % response)
+        LOGGER.info("Presign signature calculation failed: %s", response)
         return response
     LOGGER.debug("Valid presign url.")
 
