@@ -25,7 +25,12 @@ from localstack.services.generic_proxy import RegionBackend
 from localstack.services.install import SQS_BACKEND_IMPL
 from localstack.utils.analytics import event_publisher
 from localstack.utils.aws import aws_stack
-from localstack.utils.aws.aws_responses import create_sqs_system_attributes, response_regex_replace
+from localstack.utils.aws.aws_responses import (
+    create_sqs_system_attributes,
+    parse_urlencoded_data,
+    requests_response_xml,
+    response_regex_replace,
+)
 from localstack.utils.aws.dead_letter_queue import sns_error_to_dead_letter_queue
 from localstack.utils.cloudwatch.cloudwatch_util import store_cloudwatch_logs
 from localstack.utils.common import (
@@ -55,6 +60,18 @@ SKIP_PERSISTENCE_ACTIONS = [
     "Unsubscribe",
 ]
 
+SNS_PROTOCOLS = [
+    "http",
+    "https",
+    "email",
+    "email-json",
+    "sms",
+    "sqs",
+    "application",
+    "lambda",
+    "firehose",
+]
+
 
 class SNSBackend(RegionBackend):
     # maps topic ARN to list of subscriptions
@@ -143,6 +160,13 @@ class ProxyListenerSNS(PersistingProxyListener):
                 if "Endpoint" not in req_data:
                     return make_error(message="Endpoint not specified in subscription", code=400)
 
+                if req_data["Protocol"][0] not in SNS_PROTOCOLS:
+                    return make_error(
+                        message=f"Invalid parameter: Amazon SNS does not support this protocol string: "
+                        f"{req_data['Protocol'][0]}",
+                        code=400,
+                    )
+
                 if ".fifo" in req_data["Endpoint"][0] and ".fifo" not in topic_arn:
                     return make_error(
                         message="FIFO SQS Queues can not be subscribed to standard SNS topics",
@@ -210,6 +234,12 @@ class ProxyListenerSNS(PersistingProxyListener):
                 # return response here because we do not want the request to be forwarded to SNS backend
                 return make_response(req_action, message_id=message_id)
 
+            elif req_action == "PublishBatch":
+                response = publish_batch(topic_arn, req_data, headers)
+                return requests_response_xml(
+                    req_action, response, xmlns="http://sns.amazonaws.com/doc/2010-03-31/"
+                )
+
             elif req_action == "ListTagsForResource":
                 tags = do_list_tags_for_resource(topic_arn)
                 content = "<Tags/>"
@@ -383,6 +413,7 @@ def message_to_subscribers(
     headers,
     subscription_arn=None,
     skip_checks=False,
+    message_attributes=None,
 ):
     sns_backend = SNSBackend.get()
     subscriptions = sns_backend.sns_subscriptions.get(topic_arn, [])
@@ -400,6 +431,7 @@ def message_to_subscribers(
                 sns_backend,
                 subscriber,
                 subscriptions,
+                message_attributes,
             )
             for subscriber in list(subscriptions)
         ]
@@ -420,13 +452,15 @@ async def message_to_subscriber(
     sns_backend,
     subscriber,
     subscriptions,
+    message_attributes,
 ):
 
     if subscription_arn not in [None, subscriber["SubscriptionArn"]]:
         return
 
     filter_policy = json.loads(subscriber.get("FilterPolicy") or "{}")
-    message_attributes = get_message_attributes(req_data)
+    if not message_attributes:
+        message_attributes = get_message_attributes(req_data)
     if not skip_checks and not check_filter_policy(filter_policy, message_attributes):
         LOG.info(
             "SNS filter policy %s does not match attributes %s", filter_policy, message_attributes
@@ -598,7 +632,7 @@ async def message_to_subscriber(
             sns_error_to_dead_letter_queue(subscriber["SubscriptionArn"], req_data, str(exc))
         return
 
-    elif subscriber["Protocol"] == "email":
+    elif subscriber["Protocol"] in ["email", "email-json"]:
         ses_client = aws_stack.connect_to_service("ses")
         if subscriber.get("Endpoint"):
             ses_client.verify_email_address(EmailAddress=subscriber.get("Endpoint"))
@@ -607,7 +641,15 @@ async def message_to_subscriber(
             ses_client.send_email(
                 Source="admin@localstack.com",
                 Message={
-                    "Body": {"Text": {"Data": message}},
+                    "Body": {
+                        "Text": {
+                            "Data": create_sns_message_body(
+                                subscriber=subscriber, req_data=req_data, message_id=message_id
+                            )
+                            if subscriber["Protocol"] == "email-json"
+                            else message
+                        }
+                    },
                     "Subject": {"Data": "SNS-Subscriber-Endpoint"},
                 },
                 Destination={"ToAddresses": [subscriber.get("Endpoint")]},
@@ -644,6 +686,34 @@ def publish_message(topic_arn, req_data, headers, subscription_arn=None, skip_ch
     return message_id
 
 
+def publish_batch(topic_arn, req_data, headers):
+    response = {"Successful": [], "Failed": []}
+    messages = parse_urlencoded_data(
+        req_data, "PublishBatchRequestEntries.member", "MessageAttributes.entry"
+    )
+    for message in messages:
+        message_id = str(uuid.uuid4())
+        data = {}
+        data["TopicArn"] = [topic_arn]
+        data["Message"] = [message["Message"]]
+        data["Subject"] = [message["Subject"]]
+
+        message_attributes = prepare_message_attributes(message.get("MessageAttributes", []))
+        try:
+            message_to_subscribers(
+                message_id,
+                message["Message"],
+                topic_arn,
+                data,
+                headers,
+                message_attributes=message_attributes,
+            )
+            response["Successful"].append({"Id": message["Id"], "MessageId": message_id})
+        except Exception:
+            response["Failed"].append({"Id": message["Id"]})
+    return response
+
+
 def do_delete_topic(topic_arn):
     sns_backend = SNSBackend.get()
     sns_backend.sns_subscriptions.pop(topic_arn, None)
@@ -853,47 +923,35 @@ def create_sqs_message_attributes(subscriber, attributes):
 
     message_attributes = {}
     for key, value in attributes.items():
-        attribute = {"DataType": value["Type"]}
-        if value["Type"] == "Binary":
-            attribute["BinaryValue"] = base64.decodebytes(to_bytes(value["Value"]))
-        else:
-            attribute["StringValue"] = str(value.get("Value", ""))
+        if value.get("Type"):
+            attribute = {"DataType": value["Type"]}
+            if value["Type"] == "Binary":
+                attribute["BinaryValue"] = base64.decodebytes(to_bytes(value["Value"]))
+            else:
+                attribute["StringValue"] = str(value.get("Value", ""))
 
-        message_attributes[key] = attribute
+            message_attributes[key] = attribute
 
     return message_attributes
 
 
-def get_message_attributes(req_data):
+def prepare_message_attributes(message_attributes):
     attributes = {}
-    x = 1
-    while True:
-        name = req_data.get("MessageAttributes.entry." + str(x) + ".Name", [None])[0]
-        if name is not None:
-            attribute = {
-                "Type": req_data.get(
-                    "MessageAttributes.entry." + str(x) + ".Value.DataType", [None]
-                )[0]
-            }
-            string_value = req_data.get(
-                "MessageAttributes.entry." + str(x) + ".Value.StringValue", [None]
-            )[0]
-            binary_value = req_data.get(
-                "MessageAttributes.entry." + str(x) + ".Value.BinaryValue", [None]
-            )[0]
-            if string_value is not None:
-                attribute["Value"] = string_value
-            elif binary_value is not None:
-                attribute["Value"] = binary_value
-
-            attributes[name] = attribute
-            x += 1
-        else:
-            break
-
+    for attr in message_attributes:
+        attributes[attr["Name"]] = {
+            "Type": attr["Value"]["DataType"],
+            "Value": attr["Value"]["StringValue"]
+            if attr["Value"].get("StringValue", None)
+            else attr["Value"]["BinaryValue"],
+        }
     return attributes
 
 
+def get_message_attributes(req_data):
+    extracted_msg_attrs = parse_urlencoded_data(req_data, "MessageAttributes.entry")
+    return prepare_message_attributes(extracted_msg_attrs)
+
+
 def get_subscribe_attributes(req_data):
     attributes = {}
     for key in req_data.keys():
