@@ -110,7 +110,7 @@ def to_xml(data: dict, memberize: bool = True) -> ET.Element:
         elif isinstance(data_rest, str):
             parent_el.text = data_rest
         elif any(
-            [isinstance(data_rest, i) for i in [bool, str, int, float]]
+            isinstance(data_rest, i) for i in [bool, str, int, float]
         ):  # limit types for text serialization
             parent_el.text = str(data_rest)
         else:
@@ -266,7 +266,9 @@ def get_response_payload(response, as_json=False):
     return result
 
 
-def requests_response(content, status_code=200, headers={}):
+def requests_response(content, status_code=200, headers=None):
+    if headers is None:
+        headers = {}
     resp = RequestsResponse()
     headers = CaseInsensitiveDict(dict(headers or {}))
     if isinstance(content, dict):
@@ -280,7 +282,9 @@ def requests_response(content, status_code=200, headers={}):
     return resp
 
 
-def request_response_stream(stream, status_code=200, headers={}):
+def request_response_stream(stream, status_code=200, headers=None):
+    if headers is None:
+        headers = {}
     resp = RequestsResponse()
     resp.raw = stream
     resp.status_code = int(status_code)
@@ -358,7 +362,9 @@ def extract_url_encoded_param_list(req_data, pattern):
     return result
 
 
-def parse_urlencoded_data(qs_data: Union[Dict, str, bytes], top_level_attribute: str):
+def parse_urlencoded_data(
+    qs_data: Union[Dict, str, bytes], top_level_attribute: str, second_level_attribute: str = ""
+):
     # TODO: potentially find a better way than calling moto here...
     from moto.core.responses import BaseResponse
 
@@ -370,6 +376,16 @@ def parse_urlencoded_data(qs_data: Union[Dict, str, bytes], top_level_attribute:
     response = BaseResponse()
     response.querystring = qs_data
     result = response._get_multi_param(top_level_attribute, skip_result_conversion=True)
+    if second_level_attribute:
+        for r in range(len(result)):
+            second_level_result = response._get_multi_param(
+                f"{top_level_attribute}.{r+1}.{second_level_attribute}", skip_result_conversion=True
+            )
+            inner_key = second_level_attribute.split(".")[
+                0
+            ]  # "MessageAttributes.entry".split('.')[0]
+            if second_level_result:
+                result[r][inner_key] = second_level_result
     return result
 
 
